# Zetasis
Wagtail CMS page type for creating food menus of small and medium-sized restaurants.

## Installation
```pip install wagtail-restaurant```

## License

© 2020 Zetasis
This repository is licensed under the MIT license. See LICENSE for details.